% FUZJAC Calculates the Jacobian matrix of the closed loop fuzzy system.
%
%       J = fuzjac(X, Plant, Controller)
%
% Arguments:
%
%   X -> State vector where the jacobian matrix is calculated.
%
%   Plant -> Fuzzy model of the Plant.
%
%   Controlador -> Fuzzy model of the Controller.
%
%   J -> Jacobian matrix of closed loop system.
%
%                                    (  df1          df1  )
%       dx1                          | -----   ...  ----- |
%      ----- = f1(x)                 |  dx1          dxn  |
%       dt                           |                    |
%       ...                      J = |  ...    ...   ...  |
%       dxn                          |                    |
%      ----- = fn(x)                 |  dfn          dfn  |
%       dt                           | -----   ...  ----- |
%                                    (  dx1          dxn  )
%      x = [ x1 ; x2 ; ... ; xn]
%
% Fuzzy models could be a '.txt' file, a '.fis' file, or a 'FIS' variable from
% MATLAB Workspace.
%
%  See also activation, antec2mat, aproxjac, aproxlinear, conseq2mat, fis2txt,
%           fuz2mat, fuzcomb, fuzeval, fuzlinear, fuzprint, mat2antec, mat2conseq,
%           mat2fuz, subsystem, txt2fis

% #############################################################################
%
%    Copyright (C) 2004-2011
%    ANTONIO JAVIER BARRAGAN, antonio.barragan@diesia.uhu.es
%    http://www.uhu.es/antonio.barragan
%
%    Collaborators:
%    JOSE MANUEL ANDUJAR, andujar@diesia.uhu.es
%	 MARIANO J. AZNAR, marianojose.aznar@alu.uhu.es
%
%    DPTO. DE ING. ELECTRONICA, DE SISTEMAS INFORMATICOS Y AUTOMATICA
%    ETSI, UNIVERSITY OF HUELVA (SPAIN)
%
%    For more information, please contact with authors.
%
%    This software is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This software is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
% #############################################################################

